@@ -151,8 +151,9 @@ class Connection(object):
                  password=None, virtual_host=None, port=None, insist=False,
                  ssl=False, transport=None, connect_timeout=5,
                  transport_options=None, login_method=None, uri_prefix=None,
-                 heartbeat=0, failover_strategy='round-robin', **kwargs):
-        alt = []
+                 heartbeat=0, failover_strategy='round-robin',
+                 alternates=None, **kwargs):
+        alt = [] if alternates is None else alternates
         # have to spell the args out, just to get nice docstrings :(
         params = self._initial_params = {
             'hostname': hostname, 'userid': userid,
@@ -328,6 +329,29 @@ class Connection(object):
         self._debug('closed')
         self._closed = True
 
+    def collect(self, socket_timeout=None):
+        # amqp requires communication to close, we don't need that just
+        # to clear out references, Transport._collect can also be implemented
+        # by other transports that want fast after fork
+        try:
+            gc_transport = self._transport._collect
+        except AttributeError:
+            _timeo = socket.getdefaulttimeout()
+            socket.setdefaulttimeout(socket_timeout)
+            try:
+                self._close()
+            except socket.timeout:
+                pass
+            finally:
+                socket.setdefaulttimeout(_timeo)
+        else:
+            gc_transport(self._connection)
+            if self._transport:
+                self._transport.client = None
+                self._transport = None
+            self.declared_entities.clear()
+            self._connection = None
+
     def release(self):
         """Close the connection (if open)."""
         self._close()
@@ -522,12 +546,9 @@ class Connection(object):
             transport_cls = RESOLVE_ALIASES.get(transport_cls, transport_cls)
         D = self.transport.default_connection_params
 
-        if self.alt:
-            hostname = ";".join(self.alt)
-        else:
-            hostname = self.hostname or D.get('hostname')
-            if self.uri_prefix:
-                hostname = '%s+%s' % (self.uri_prefix, hostname)
+        hostname = self.hostname or D.get('hostname')
+        if self.uri_prefix:
+            hostname = '%s+%s' % (self.uri_prefix, hostname)
 
         info = (('hostname', hostname),
                 ('userid', self.userid or D.get('userid')),
@@ -542,6 +563,10 @@ class Connection(object):
                 ('login_method', self.login_method or D.get('login_method')),
                 ('uri_prefix', self.uri_prefix),
                 ('heartbeat', self.heartbeat))
+
+        if self.alt:
+            info += (('alternates', self.alt),)
+
         return info
 
     def info(self):
@@ -910,6 +935,9 @@ class Resource(object):
         else:
             self.close_resource(resource)
 
+    def collect_resource(self, resource):
+        pass
+
     def force_close_all(self):
         """Closes and removes all resources in the pool (also those in use).
 
@@ -919,32 +947,27 @@ class Resource(object):
         """
         dirty = self._dirty
         resource = self._resource
-        while 1:
+        while 1:  # - acquired
             try:
                 dres = dirty.pop()
             except KeyError:
                 break
             try:
-                self.close_resource(dres)
+                self.collect_resource(dres)
             except AttributeError:  # Issue #78
                 pass
-
-        mutex = getattr(resource, 'mutex', None)
-        if mutex:
-            mutex.acquire()
-        try:
-            while 1:
-                try:
-                    res = resource.queue.pop()
-                except IndexError:
-                    break
-                try:
-                    self.close_resource(res)
-                except AttributeError:
-                    pass  # Issue #78
-        finally:
-            if mutex:  # pragma: no cover
-                mutex.release()
+        while 1:  # - available
+            # deque supports '.clear', but lists do not, so for that
+            # reason we use pop here, so that the underlying object can
+            # be any object supporting '.pop' and '.append'.
+            try:
+                res = resource.queue.pop()
+            except IndexError:
+                break
+            try:
+                self.collect_resource(res)
+            except AttributeError:
+                pass  # Issue #78
 
     if os.environ.get('KOMBU_DEBUG_POOL'):  # pragma: no cover
         _orig_acquire = acquire
@@ -993,6 +1016,9 @@ class ConnectionPool(Resource):
     def close_resource(self, resource):
         resource._close()
 
+    def collect_resource(self, resource, socket_timeout=0.1):
+        return resource.collect(socket_timeout)
+
     @contextmanager
     def acquire_channel(self, block=False):
         with self.acquire(block=block) as connection:
