@@ -123,6 +123,7 @@ class Exchange(MaybeChannelBound):
     type = 'direct'
     durable = True
     auto_delete = False
+    passive = False
     delivery_mode = PERSISTENT_DELIVERY_MODE
 
     attrs = (
@@ -130,6 +131,7 @@ class Exchange(MaybeChannelBound):
         ('type', None),
         ('arguments', None),
         ('durable', bool),
+        ('passive', bool),
         ('auto_delete', bool),
         ('delivery_mode', lambda m: DELIVERY_MODES.get(m) or m),
     )
@@ -143,7 +145,7 @@ class Exchange(MaybeChannelBound):
     def __hash__(self):
         return hash('E|%s' % (self.name, ))
 
-    def declare(self, nowait=False, passive=False):
+    def declare(self, nowait=False, passive=None):
         """Declare the exchange.
 
         Creates the exchange on the broker.
@@ -152,6 +154,7 @@ class Exchange(MaybeChannelBound):
             response will not be waited for. Default is :const:`False`.
 
         """
+        passive = self.passive if passive is None else passive
         if self.name:
             return self.channel.exchange_declare(
                 exchange=self.name, type=self.type, durable=self.durable,
@@ -489,7 +492,7 @@ class Queue(MaybeChannelBound):
             self.exchange.declare(nowait)
         self.queue_declare(nowait, passive=False)
 
-        if self.exchange is not None:
+        if self.exchange and self.exchange.name:
             self.queue_bind(nowait)
 
         # - declare extra/multi-bindings.
@@ -541,8 +544,8 @@ class Queue(MaybeChannelBound):
         Returns the message instance if a message was available,
         or :const:`None` otherwise.
 
-        :keyword no_ack: If set messages received does not have to
-            be acknowledged.
+        :keyword no_ack: If enabled the broker will automatically
+            ack messages.
 
         This method provides direct access to the messages in a
         queue using a synchronous dialogue, designed for
@@ -575,8 +578,8 @@ class Queue(MaybeChannelBound):
           can use the same consumer tags. If this field is empty
           the server will generate a unique tag.
 
-        :keyword no_ack: If set messages received does not have to
-            be acknowledged.
+        :keyword no_ack: If enabled the broker will automatically ack
+            messages.
 
         :keyword nowait: Do not wait for a reply.
 
