@@ -14,6 +14,7 @@ from itertools import chain
 from .connection import Resource
 from .messaging import Producer
 from .utils import EqualityDict
+from .utils.functional import promise
 
 __all__ = ['ProducerPool', 'PoolGroup', 'register_group',
            'connections', 'producers', 'get_limit', 'set_limit', 'reset']
@@ -44,7 +45,7 @@ class ProducerPool(Resource):
             raise
 
     def new(self):
-        return lambda: self.create_producer()
+        return promise(self.create_producer)
 
     def setup(self):
         if self.limit:
