@@ -5,6 +5,8 @@ from __future__ import with_statement
 
 import sys
 
+from base64 import b64decode
+
 from kombu.serialization import (registry, register, SerializerNotInstalled,
                                  raw_encode, register_yaml, register_msgpack,
                                  decode, bytes_t, pickle, pickle_protocol,
@@ -57,12 +59,11 @@ msgpack_py_data = dict(py_data)
 msgpack_py_data['list'] = tuple(msgpack_py_data['list'])
 # Unicode chars are lost in transmit :(
 msgpack_py_data['unicode'] = 'Th quick brown fox jumps over th lazy dog'
-msgpack_data = """\
-\x85\xa3int\n\xa5float\xcb@\t!\xfbS\xc8\xd4\xf1\xa4list\
-\x94\xa6george\xa5jerry\xa6elaine\xa5cosmo\xa6string\xda\
-\x00+The quick brown fox jumps over the lazy dog\xa7unicode\
-\xda\x00)Th quick brown fox jumps over th lazy dog\
-"""
+msgpack_data = b64decode("""\
+haNpbnQKpWZsb2F0y0AJIftTyNTxpGxpc3SUpmdlb3JnZaVqZXJyeaZlbGFpbmWlY29zbW+mc3Rya\
+W5n2gArVGhlIHF1aWNrIGJyb3duIGZveCBqdW1wcyBvdmVyIHRoZSBsYXp5IGRvZ6d1bmljb2Rl2g\
+ApVGggcXVpY2sgYnJvd24gZm94IGp1bXBzIG92ZXIgdGggbGF6eSBkb2c=\
+""")
 
 
 def say(m):
