@@ -57,10 +57,10 @@ class test_Channel(amqplibCase):
         self.assertFalse(self.channel.no_ack_consumers)
 
     def test_prepare_message(self):
-        x = self.channel.prepare_message('foobar', 10,
-                'application/data', 'utf-8',
-                properties={})
-        self.assertTrue(x)
+        self.assertTrue(self.channel.prepare_message(
+            'foobar', 10, 'application/data', 'utf-8',
+            properties={},
+        ))
 
     def test_message_to_python(self):
         message = Mock()
