@@ -2,7 +2,7 @@ from __future__ import absolute_import
 
 from nose import SkipTest
 
-from kombu.connection import Connection
+from kombu import Connection
 
 from kombu.tests.utils import TestCase, skip_if_not_module
 
@@ -42,14 +42,16 @@ class test_mongodb(TestCase):
         client = c.channels[0].client
         self.assertEquals(client.name, 'dbname')
 
-        url = 'mongodb://localhost,example.org:29017/dbname'
+        url = 'mongodb://localhost,localhost:29017/dbname'
         c = Connection(url, transport=Transport).connect()
         client = c.channels[0].client
 
         nodes = client.connection.nodes
-        self.assertEquals(len(nodes), 2)
-        self.assertTrue(('example.org', 29017) in nodes)
-        self.assertEquals(client.name, 'dbname')
+        # If there's just 1 node it is because we're  connecting to a single
+        # server instead of a repl / mongoss.
+        if len(nodes) == 2:
+            self.assertTrue(('localhost', 29017) in nodes)
+            self.assertEquals(client.name, 'dbname')
 
         # Passing options breaks kombu's _init_params method
         # url = 'mongodb://localhost,localhost2:29017/dbname?safe=true'
@@ -60,10 +62,28 @@ class test_mongodb(TestCase):
         c = Connection(url, transport=Transport).connect()
         client = c.channels[0].client
 
-        url = 'mongodb://username:password@localhost/dbname'
+        # Login to admin db since there's no db specified
+        url = "mongodb://adminusername:adminpassword@localhost"
         c = Connection(url, transport=Transport).connect()
-        # Assuming there's no user 'username' with password 'password'
+        client = c.channels[0].client
+        self.assertEquals(client.name, "kombu_default")
+
+        # Lets make sure that using admin db doesn't break anything
+        # when no user is specified
+        url = "mongodb://localhost"
+        c = Connection(url, transport=Transport).connect()
+        client = c.channels[0].client
+
+        # Assuming there's user 'username' with password 'password'
         # configured in mongodb
+        url = "mongodb://username:password@localhost/dbname"
+        c = Connection(url, transport=Transport).connect()
+        client = c.channels[0].client
+
+        # Assuming there's no user 'nousername' with password 'nopassword'
+        # configured in mongodb
+        url = "mongodb://nousername:nopassword@localhost/dbname"
+        c = Connection(url, transport=Transport).connect()
 
         # Needed, otherwise the error would be rose before
         # the assertRaises is called
