@@ -10,14 +10,11 @@ from kombu.tests.utils import TestCase
 
 class test_transport(TestCase):
 
-    def test_resolve_transport__no_class_name(self):
-        with self.assertRaises(KeyError):
-            transport.resolve_transport('nonexistant')
-
     def test_resolve_transport_when_callable(self):
-        self.assertTupleEqual(transport.resolve_transport(
-                lambda: 'kombu.transport.memory.Transport'),
-                ('kombu.transport.memory', 'Transport'))
+        from kombu.transport.memory import Transport
+        self.assertIs(transport.resolve_transport(
+            'kombu.transport.memory:Transport'),
+            Transport)
 
 
 class test_transport_gettoq(TestCase):
