@@ -19,8 +19,9 @@ class test_get_manager(TestCase):
         with patch('pyrabbit.Client', create=True) as Client:
             manager = Connection('amqp://').get_manager()
             self.assertIsNotNone(manager)
-            Client.assert_called_with('localhost:55672',
-                    'guest', 'guest')
+            Client.assert_called_with(
+                'localhost:55672', 'guest', 'guest',
+            )
 
     @module_exists('pyrabbit')
     def test_transport_options(self):
@@ -32,5 +33,6 @@ class test_get_manager(TestCase):
                 'manager_password': 'bosco',
             }).get_manager()
             self.assertIsNotNone(manager)
-            Client.assert_called_with('admin.mq.vandelay.com:808',
-                    'george', 'bosco')
+            Client.assert_called_with(
+                'admin.mq.vandelay.com:808', 'george', 'bosco',
+            )
