@@ -9,6 +9,7 @@ kombu.transport.librabbitmq
 """
 from __future__ import absolute_import
 
+import os
 import socket
 
 try:
@@ -28,6 +29,10 @@ from . import base
 
 DEFAULT_PORT = 5672
 
+NO_SSL_ERROR = """\
+ssl not supported by librabbitmq, please use pyamqp:// or stunnel\
+"""
+
 
 class Message(base.Message):
 
@@ -98,6 +103,8 @@ class Transport(base.Transport):
         for name, default_value in self.default_connection_params.items():
             if not getattr(conninfo, name, None):
                 setattr(conninfo, name, default_value)
+        if conninfo.ssl:
+            raise NotImplementedError(NO_SSL_ERROR)
         conn = self.Connection(host=conninfo.host,
                                userid=conninfo.userid,
                                password=conninfo.password,
@@ -105,15 +112,30 @@ class Transport(base.Transport):
                                login_method=conninfo.login_method,
                                insist=conninfo.insist,
                                ssl=conninfo.ssl,
-                               connect_timeout=conninfo.connect_timeout)
+                               connect_timeout=conninfo.connect_timeout,
+                               **conninfo.transport_options or {})
         conn.client = self.client
         self.client.drain_events = conn.drain_events
         return conn
 
     def close_connection(self, connection):
         """Close the AMQP broker connection."""
+        self.client.drain_events = None
         connection.close()
 
+    def _collect(self, connection):
+        if connection is not None:
+            for channel in connection.channels.itervalues():
+                channel.connection = None
+            try:
+                os.close(connection.fileno())
+            except OSError:
+                pass
+            connection.channels.clear()
+            connection.callbacks.clear()
+        self.client.drain_events = None
+        self.client = None
+
     def verify_connection(self, connection):
         return connection.connected
 
