@@ -4,9 +4,6 @@ kombu.transport.memory
 
 In-memory transport.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -58,3 +55,9 @@ class Transport(virtual.Transport):
 
     #: memory backend state is global.
     state = virtual.BrokerState()
+
+    driver_type = 'memory'
+    driver_name = 'memory'
+
+    def driver_version(self):
+        return 'N/A'
