@@ -707,11 +707,12 @@ class Channel(virtual.Channel):
         return self._queue_cycle[0:active]
 
     def _rotate_cycle(self, used):
-        """
-        Move most recently used queue to end of list
-        """
-        index = self._queue_cycle.index(used)
-        self._queue_cycle.append(self._queue_cycle.pop(index))
+        """Move most recently used queue to end of list."""
+        cycle = self._queue_cycle
+        try:
+            cycle.append(cycle.pop(cycle.index(used)))
+        except ValueError:
+            pass
 
     def _get_response_error(self):
         from redis import exceptions
