@@ -4,9 +4,6 @@
 
     Consumer utilities.
 
-    :copyright: (c) 2009 - 2012 by Ask Solem.
-    :license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -48,5 +45,5 @@ class FairCycle(object):
         pass
 
     def __repr__(self):
-        return "<FairCycle: %r/%r %r>" % (self.pos, len(self.resources),
+        return '<FairCycle: %r/%r %r>' % (self.pos, len(self.resources),
                                           self.resources, )
